==> bot-fw-custom-actions-v6-1.0.0.tgz: package/src/botFrameworkOAuthCustomActions.ts <==
import {
  Expression,
  NumberExpression,
  NumberExpressionConverter,
  StringExpression,
  StringExpressionConverter,
} from "adaptive-expressions";
import { Count } from "adaptive-expressions/lib/builtinFunctions";

import {
  Converter,
  ConverterFactory,
  Dialog,
  DialogConfiguration,
  DialogContext,
  DialogTurnResult,
} from "botbuilder-dialogs";

import { MicrosoftAppCredentials } from "botframework-connector";
import { OAuthActions } from "./actions/oAuthActions";

export interface BotFrameworkOAuthCustomActionsConfiguration extends DialogConfiguration {
  action: string | string | Expression | StringExpression;
  connectionName: string | string | Expression | StringExpression;
  channelId: string | string | Expression | StringExpression;
  msAppId: string | string | Expression | StringExpression;
  msAppPwd: string | string | Expression | StringExpression;
  resultProperty?: string | Expression | StringExpression;
}

export class BotFrameworkOAuthCustomActions
  extends Dialog
  implements BotFrameworkOAuthCustomActionsConfiguration {
  public static $kind = "BotbuilderSamples.BotFrameworkOAuthCustomActions";

  public action: StringExpression = new StringExpression('');
  public channelId: StringExpression = new StringExpression('');
  public connectionName: StringExpression = new StringExpression('');
  public msAppId: StringExpression = new StringExpression('');
  public msAppPwd: StringExpression = new StringExpression('');
  public resultProperty?: StringExpression;

  public getConverter(
    property: keyof BotFrameworkOAuthCustomActionsConfiguration
  ): Converter | ConverterFactory {
    switch (property) {
      case "action":
        return new StringExpressionConverter();
      case "connectionName":
        return new StringExpressionConverter();
      case "channelId":
        return new StringExpressionConverter();
      case "msAppId":
        return new StringExpressionConverter();
      case "msAppPwd":
        return new StringExpressionConverter();  
      case "resultProperty":
        return new StringExpressionConverter();
      default:
        return super.getConverter(property);
    }
  }

  public async beginDialog(dc: DialogContext): Promise<DialogTurnResult> {
    const action = this.action.getValue(dc.state);
    let result;

    if (action === 'SIGNOUT') {
      result = await OAuthActions.signout(dc, this.connectionName.getValue(dc.state), this.msAppId.getValue(dc.state), this.msAppPwd.getValue(dc.state))
    }

    if (this.resultProperty) {
      dc.state.setValue(this.resultProperty.getValue(dc.state), result);
    }
    return dc.endDialog(result);
  }

  protected onComputeId(): string {
    return "BotbuilderSamples.BotFrameworkOAuthCustomActions";
  }
}

==> bot-fw-custom-actions-v8-1.0.0.tgz: package/src/botFrameworkOAuthCustomActions.ts <==
import {
  Expression,
  NumberExpression,
  NumberExpressionConverter,
  StringExpression,
  StringExpressionConverter,
} from "adaptive-expressions";
import { Count } from "adaptive-expressions/lib/builtinFunctions";

import {
  Converter,
  ConverterFactory,
  Dialog,
  DialogConfiguration,
  DialogContext,
  DialogTurnResult,
} from "botbuilder-dialogs";

import { MicrosoftAppCredentials } from "botframework-connector";
import { OAuthActions } from "./actions/oAuthActions";

export interface BotFrameworkOAuthCustomActionsConfiguration extends DialogConfiguration {
  action: string | string | Expression | StringExpression;
  connectionName: string | string | Expression | StringExpression;
  userId: string | string | Expression | StringExpression;
  channelId: string | string | Expression | StringExpression;
  msAppId: string | string | Expression | StringExpression;
  msAppPwd: string | string | Expression | StringExpression;
  resultProperty?: string | Expression | StringExpression;
}

export class BotFrameworkOAuthCustomActions
  extends Dialog
  implements BotFrameworkOAuthCustomActionsConfiguration {
  public static $kind = "BotbuilderSamples.BotFrameworkOAuthCustomActions";

  public action: StringExpression = new StringExpression('');
  public channelId: StringExpression = new StringExpression('');
  public connectionName: StringExpression = new StringExpression('');
  public userId: StringExpression = new StringExpression('');
  public msAppId: StringExpression = new StringExpression('');
  public msAppPwd: StringExpression = new StringExpression('');
  public resultProperty?: StringExpression;

  public getConverter(
    property: keyof BotFrameworkOAuthCustomActionsConfiguration
  ): Converter | ConverterFactory {
    switch (property) {
      case "action":
        return new StringExpressionConverter();
      case "connectionName":
        return new StringExpressionConverter();
      case "userId":
        return new StringExpressionConverter();
      case "channelId":
        return new StringExpressionConverter();
      case "msAppId":
        return new StringExpressionConverter();
      case "msAppPwd":
        return new StringExpressionConverter();  
      case "resultProperty":
        return new StringExpressionConverter();
      default:
        return super.getConverter(property);
    }
  }

  public async beginDialog(dc: DialogContext): Promise<DialogTurnResult> {
    const action = this.action.getValue(dc.state);
    let result;

    if (action === 'SIGNOUT') {
      result = await OAuthActions.signout(dc, this.userId.getValue(dc.state), this.connectionName.getValue(dc.state), this.msAppId.getValue(dc.state), this.msAppPwd.getValue(dc.state))
    }

    if (this.resultProperty) {
      dc.state.setValue(this.resultProperty.getValue(dc.state), result);
    }
    return dc.endDialog(result);
  }

  protected onComputeId(): string {
    return "BotbuilderSamples.BotFrameworkOAuthCustomActions";
  }
}
